MultiTanProcessor
=================

.. currentmodule:: toasty.multi_tan

.. autoclass:: MultiTanProcessor
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MultiTanProcessor.compute_global_pixelization
      ~MultiTanProcessor.tile

   .. rubric:: Methods Documentation

   .. automethod:: compute_global_pixelization
   .. automethod:: tile
